@@ -5,6 +5,7 @@ use libs::gh_emoji::Replacer as EmojiReplacer;
 use libs::once_cell::sync::Lazy;
 use libs::pulldown_cmark as cmark;
 use libs::tera;
+use utils::net::is_external_link;
 
 use crate::context::RenderContext;
 use errors::{Context, Error, Result};
@@ -56,7 +57,10 @@ fn insert_many<T>(input: &mut Vec<T>, elem_to_insert: Vec<(usize, T)>) {
 
 /// Colocated asset links refers to the files in the same directory.
 fn is_colocated_asset_link(link: &str) -> bool {
-    !link.starts_with('/') && !link.starts_with('#') && !STARTS_WITH_SCHEMA_RE.is_match(link)
+    !link.starts_with('/')
+        && !link.starts_with("..")
+        && !link.starts_with('#')
+        && !STARTS_WITH_SCHEMA_RE.is_match(link)
 }
 
 #[derive(Debug)]
@@ -130,11 +134,6 @@ fn find_anchor(anchors: &[String], name: String, level: u16) -> String {
     find_anchor(anchors, name, level + 1)
 }
 
-/// Returns whether a link starts with an HTTP(s) scheme.
-fn is_external_link(link: &str) -> bool {
-    link.starts_with("http:") || link.starts_with("https:")
-}
-
 fn fix_link(
     link_type: LinkType,
     link: &str,
@@ -171,6 +170,8 @@ fn fix_link(
                 }
             }
         }
+    } else if is_colocated_asset_link(link) {
+        format!("{}{}", context.current_page_permalink, link)
     } else if is_external_link(link) {
         external_links.push(link.to_owned());
         link.to_owned()
@@ -477,13 +478,10 @@ pub fn markdown_to_html(
         }
 
         // We remove all the empty things we might have pushed before so we don't get some random \n
-        events = events
-            .into_iter()
-            .filter(|e| match e {
-                Event::Text(text) | Event::Html(text) => !text.is_empty(),
-                _ => true,
-            })
-            .collect();
+        events.retain(|e| match e {
+            Event::Text(text) | Event::Html(text) => !text.is_empty(),
+            _ => true,
+        });
 
         let heading_refs = get_heading_refs(&events);
 
@@ -537,12 +535,10 @@ pub fn markdown_to_html(
                 .context("Failed to render anchor link template")?;
                 if context.insert_anchor != InsertAnchor::Heading {
                     anchors_to_insert.push((anchor_idx, Event::Html(anchor_link.into())));
-                } else {
-                    if let Some(captures) = A_HTML_TAG.captures(&anchor_link) {
-                        let opening_tag = captures.get(1).map_or("", |m| m.as_str()).to_string();
-                        anchors_to_insert.push((start_idx + 1, Event::Html(opening_tag.into())));
-                        anchors_to_insert.push((end_idx, Event::Html("</a>".into())));
-                    }
+                } else if let Some(captures) = A_HTML_TAG.captures(&anchor_link) {
+                    let opening_tag = captures.get(1).map_or("", |m| m.as_str()).to_string();
+                    anchors_to_insert.push((start_idx + 1, Event::Html(opening_tag.into())));
+                    anchors_to_insert.push((end_idx, Event::Html("</a>".into())));
                 }
             }
 
@@ -597,6 +593,7 @@ mod tests {
     fn test_is_external_link() {
         assert!(is_external_link("http://example.com/"));
         assert!(is_external_link("https://example.com/"));
+        assert!(is_external_link("www.example.com"));
         assert!(is_external_link("https://example.com/index.html#introduction"));
 
         assert!(!is_external_link("mailto:user@example.com"));
@@ -606,4 +603,22 @@ mod tests {
 
         assert!(!is_external_link("http.jpg"))
     }
+
+    #[test]
+    // Tests for link  that points to files in the same directory
+    fn test_is_colocated_asset_link_true() {
+        let links: [&str; 3] = ["./same-dir.md", "file.md", "qwe.js"];
+        for link in links {
+            assert!(is_colocated_asset_link(link));
+        }
+    }
+
+    #[test]
+    // Tests for files where the link points to a different directory
+    fn test_is_colocated_asset_link_false() {
+        let links: [&str; 2] = ["/other-dir/file.md", "../sub-dir/file.md"];
+        for link in links {
+            assert!(!is_colocated_asset_link(link));
+        }
+    }
 }
